@@ -121,7 +121,7 @@ function pagelayer_page_footer(){
 	</table>
 	<br />';
 	
-	if(!defined('SITEPAD')){
+	if(empty($GLOBALS['sitepad'])){
 	
 		echo '<div style="width:45%;background:#FFF;padding:15px; margin:auto">
 		<b>Let your followers know that you use Pagelayer to build your website :</b>
@@ -155,51 +155,156 @@ echo '
 
 function pagelayer_settings_page(){
 
-	$post_type = array();
-	$exclude = [ 'attachment', 'pagelayer-template' ];
-	$pt_objects = get_post_types(['public' => true,], 'objects');
-
-	foreach ( $pt_objects as $pt_slug => $type ) {
-		
-		if ( in_array( $pt_slug, $exclude ) ) {
-			continue;
-		}
-		
-		$post_type[$pt_slug] = $type->labels->name;
-	}
-
-	$support_ept = get_option( 'pl_support_ept', ['post', 'page']);
-
-	$option_name = 'pl_gen_setting';
+	$option_name = 'pl_gen_setting' ;
 	$new_value = '';
+
+	if(isset($_REQUEST['pl_gen_setting'])){
+		$new_value = $_REQUEST['pl_gen_setting'];
+		
+		if ( get_option( $option_name ) !== false ) {
 	
-	if(isset($_REQUEST['submit'])){
-		check_admin_referer('pagelayer-options');
+			// The option already exists, so we just update it.
+			update_option( $option_name, $new_value );
+
+		} else {
+
+			// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+			$deprecated = null;
+			$autoload = 'no';
+			add_option( $option_name, $new_value, $deprecated, $autoload );
+		}
+
 	}
 	
 	if(isset($_REQUEST['pl_support_ept'])){
 
 		$pl_support_ept = $_REQUEST['pl_support_ept'];
 		
-		foreach($pl_support_ept as $k => $v){
-			if(empty($post_type[$v])){
-				unset($pl_support_ept[$k]);
-			}
+		if ( get_option( 'pl_support_ept' ) !== false ) {
+	
+			// The option already exists, so we just update it.
+			update_option( 'pl_support_ept', $pl_support_ept );
+
+		} else {
+
+			// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+			$deprecated = null;
+			$autoload = 'no';
+			$pl_support_ept = ['post', 'page'];
+			add_option( 'pl_support_ept', $pl_support_ept, $deprecated, $autoload );
 		}
-		
-		// Update it
-		update_option('pl_support_ept', $pl_support_ept );
-		
-		$support_ept = get_option( 'pl_support_ept');
-		
 	}
 	
 	
+	
 	if(isset($_REQUEST['pagelayer_icons_set'])){
 		$pagelayer_icons_set = $_REQUEST['pagelayer_icons_set'];
 		
-		// Update it
-		update_option('pagelayer_icons_set', $pagelayer_icons_set);
+		if ( get_option( 'pagelayer_icons_set' ) !== false ) {
+	
+			// The option already exists, so we just update it.
+			update_option( 'pagelayer_icons_set', $pagelayer_icons_set);
+
+		} else {
+			// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+			$deprecated = null;
+			$autoload = 'no';
+			//$pagelayer_icons_set = [];
+			add_option( 'pagelayer_icons_set', $pagelayer_icons_set, $deprecated, $autoload );
+		}
+	}
+	
+	if(isset($_REQUEST['pagelayer_content_width'])){
+
+		$content_width = $_REQUEST['pagelayer_content_width'];
+		
+		if ( get_option( 'pagelayer_content_width' ) !== false ) {
+	
+			// The option already exists, so we just update it.
+			update_option( 'pagelayer_content_width', $content_width );
+
+		} else {
+
+			// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+			$deprecated = null;
+			$autoload = 'no';
+			add_option( 'pagelayer_content_width', $content_width, $deprecated, $autoload );
+		}
+	}
+	
+	// Tablet breakpoint 
+	if(isset($_REQUEST['pagelayer_tablet_breakpoint'])){
+
+		$tablet_breakpoint = $_REQUEST['pagelayer_tablet_breakpoint'];
+		
+		if ( get_option( 'pagelayer_tablet_breakpoint' ) !== false ) {
+	
+			// The option already exists, so we just update it.
+			update_option( 'pagelayer_tablet_breakpoint', $tablet_breakpoint );
+
+		} else {
+
+			// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+			$deprecated = null;
+			$autoload = 'no';
+			add_option( 'pagelayer_tablet_breakpoint', $tablet_breakpoint, $deprecated, $autoload );
+		}
+	}
+	
+	
+	// Mobile breakpoint 
+	if(isset($_REQUEST['pagelayer_mobile_breakpoint'])){
+
+		$tablet_breakpoint = $_REQUEST['pagelayer_mobile_breakpoint'];
+		
+		if ( get_option( 'pagelayer_mobile_breakpoint' ) !== false ) {
+	
+			// The option already exists, so we just update it.
+			update_option( 'pagelayer_mobile_breakpoint', $tablet_breakpoint );
+
+		} else {
+
+			// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+			$deprecated = null;
+			$autoload = 'no';
+			add_option( 'pagelayer_mobile_breakpoint', $tablet_breakpoint, $deprecated, $autoload );
+		}
+	}
+	
+	if(isset($_REQUEST['pagelayer_between_widgets'])){
+
+		$space_widgets = $_REQUEST['pagelayer_between_widgets'];
+		
+		if ( get_option( 'pagelayer_between_widgets' ) !== false ) {
+	
+			// The option already exists, so we just update it.
+			update_option( 'pagelayer_between_widgets', $space_widgets );
+
+		} else {
+
+			// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+			$deprecated = null;
+			$autoload = 'no';
+			add_option( 'pagelayer_between_widgets', $space_widgets, $deprecated, $autoload );
+		}
+	}
+	
+	if(isset($_REQUEST['pagelayer_body_font'])){
+
+		$body_font = $_REQUEST['pagelayer_body_font'];
+		
+		if ( get_option( 'pagelayer_body_font' ) !== false ) {
+	
+			// The option already exists, so we just update it.
+			update_option( 'pagelayer_body_font', $body_font );
+
+		} else {
+
+			// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+			$deprecated = null;
+			$autoload = 'no';
+			add_option( 'pagelayer_body_font', $body_font, $deprecated, $autoload );
+		}
 	}
 	
 	$socials = ['pagelayer-facebook-url','pagelayer-twitter-url','pagelayer-instagram-url','pagelayer-linkedin-url','pagelayer-youtube-url','pagelayer-gplus-url','pagelayer-copyright','pagelayer-phone','pagelayer-address'];
@@ -215,8 +320,18 @@ function pagelayer_settings_page(){
 
 		$to_email = $_REQUEST['pagelayer_cf_to_email'];
 		
-		update_option( 'pagelayer_cf_to_email', $to_email );
-		
+		if ( get_option( 'pagelayer_cf_to_email' ) !== false ) {
+	
+			// The option already exists, so we just update it.
+			update_option( 'pagelayer_cf_to_email', $to_email );
+
+		} else {
+
+			// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+			$deprecated = null;
+			$autoload = 'no';
+			add_option( 'pagelayer_cf_to_email', $to_email, $deprecated, $autoload );
+		}
 	}
 		
 	if(defined('PAGELAYER_PREMIUM')){
@@ -225,72 +340,72 @@ function pagelayer_settings_page(){
 
 			$subject = $_REQUEST['pagelayer_cf_subject'];
 			
-			update_option('pagelayer_cf_subject', $subject, 'no');
-			
-		}
+			if ( get_option( 'pagelayer_cf_subject' ) !== false ) {
 		
-		if(isset($_REQUEST['pagelayer_cf_headers'])){
+				// The option already exists, so we just update it.
+				update_option( 'pagelayer_cf_subject', $subject );
 
-			$subject = $_REQUEST['pagelayer_cf_headers'];
-			
-			update_option('pagelayer_cf_headers', $subject, 'no');
-			
-		}
-		
-		if(isset($_REQUEST['pagelayer_cf_from_email'])){
+			} else {
 
-			$subject = $_REQUEST['pagelayer_cf_from_email'];
-			
-			update_option('pagelayer_cf_from_email', $subject, 'no');
-			
+				// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+				$deprecated = null;
+				$autoload = 'no';
+				add_option( 'pagelayer_cf_subject', $subject, $deprecated, $autoload );
+			}
 		}
 		
 		if(isset($_REQUEST['pagelayer_cf_success'])){
 
 			$success = $_REQUEST['pagelayer_cf_success'];
 			
-			update_option( 'pagelayer_cf_success', $success, 'no');
-			
+			if ( get_option( 'pagelayer_cf_success' ) !== false ) {
+		
+				// The option already exists, so we just update it.
+				update_option( 'pagelayer_cf_success', $success );
+
+			} else {
+
+				// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+				$deprecated = null;
+				$autoload = 'no';
+				add_option( 'pagelayer_cf_success', $success, $deprecated, $autoload );
+			}
 		}
 		
 		if(isset($_REQUEST['pagelayer_cf_failed'])){
 
 			$failed = $_REQUEST['pagelayer_cf_failed'];
 			
-			update_option( 'pagelayer_cf_failed', $failed, 'no');
-			
-		}
+			if ( get_option( 'pagelayer_cf_failed' ) !== false ) {
 		
-		if(isset($_REQUEST['pagelayer_recaptcha_failed'])){
+				// The option already exists, so we just update it.
+				update_option( 'pagelayer_cf_failed', $failed );
 
-			$failed = $_REQUEST['pagelayer_recaptcha_failed'];
-			
-			update_option( 'pagelayer_recaptcha_failed', $failed, 'no');
-			
+			} else {
+
+				// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+				$deprecated = null;
+				$autoload = 'no';
+				add_option( 'pagelayer_cf_failed', $failed, $deprecated, $autoload );
+			}
 		}
 		
 		if(isset($_REQUEST['pagelayer_google_captcha'])){
 
 			$captcha = $_REQUEST['pagelayer_google_captcha'];
 			
-			update_option( 'pagelayer_google_captcha', $captcha );
-			
-		}
+			if ( get_option( 'pagelayer_google_captcha' ) !== false ) {
 		
-		if(isset($_REQUEST['pagelayer_google_captcha_secret'])){
+				// The option already exists, so we just update it.
+				update_option( 'pagelayer_google_captcha', $captcha );
 
-			$captcha_secret = $_REQUEST['pagelayer_google_captcha_secret'];
-			
-			update_option( 'pagelayer_google_captcha_secret', $captcha_secret );
-			
-		}
-		
-		if(isset($_REQUEST['pagelayer_google_captcha_lang'])){
+			} else {
 
-			$captcha_secret = $_REQUEST['pagelayer_google_captcha_lang'];
-			
-			update_option( 'pagelayer_google_captcha_lang', $captcha_secret );
-			
+				// The option hasn't been added yet. We'll add it with $autoload set to 'no'.
+				$deprecated = null;
+				$autoload = 'no';
+				add_option( 'pagelayer_google_captcha', $captcha, $deprecated, $autoload );
+			}
 		}
 		
 		// Facebook APP ID
@@ -302,116 +417,42 @@ function pagelayer_settings_page(){
 		}
 	}
 
-	// reCAPTCHA Langs
-	$recap_lang[''] = 'Auto Detect';
-	$recap_lang['ar'] = 'Arabic';
-	$recap_lang['af'] = 'Afrikaans';
-	$recap_lang['am'] = 'Amharic';
-	$recap_lang['hy'] = 'Armenian';
-	$recap_lang['az'] = 'Azerbaijani';
-	$recap_lang['eu'] = 'Basque';
-	$recap_lang['bn'] = 'Bengali';
-	$recap_lang['bg'] = 'Bulgarian';
-	$recap_lang['ca'] = 'Catalan';
-	$recap_lang['zh-HK'] = 'Chinese (Hong Kong)';
-	$recap_lang['zh-CN'] = 'Chinese (Simplified)';
-	$recap_lang['zh-TW'] = 'Chinese (Traditional)';
-	$recap_lang['hr'] = 'Croatian';
-	$recap_lang['cs'] = 'Czech';
-	$recap_lang['da'] = 'Danish';
-	$recap_lang['nl'] = 'Dutch';
-	$recap_lang['en-GB'] = 'English (UK)';
-	$recap_lang['en'] = 'English (US)';
-	$recap_lang['et'] = 'Estonian';
-	$recap_lang['fil'] = 'Filipino';
-	$recap_lang['fi'] = 'Finnish';
-	$recap_lang['fr'] = 'French';
-	$recap_lang['fr-CA'] = 'French (Canadian)';
-	$recap_lang['gl'] = 'Galician';
-	$recap_lang['ka'] = 'Georgian';
-	$recap_lang['de'] = 'German';
-	$recap_lang['de-AT'] = 'German (Austria)';
-	$recap_lang['de-CH'] = 'German (Switzerland)';
-	$recap_lang['el'] = 'Greek';
-	$recap_lang['gu'] = 'Gujarati';
-	$recap_lang['iw'] = 'Hebrew';
-	$recap_lang['hi'] = 'Hindi';
-	$recap_lang['hu'] = 'Hungarain';
-	$recap_lang['is'] = 'Icelandic';
-	$recap_lang['id'] = 'Indonesian';
-	$recap_lang['it'] = 'Italian';
-	$recap_lang['ja'] = 'Japanese';
-	$recap_lang['kn'] = 'Kannada';
-	$recap_lang['ko'] = 'Korean';
-	$recap_lang['lo'] = 'Laothian';
-	$recap_lang['lv'] = 'Latvian';
-	$recap_lang['lt'] = 'Lithuanian';
-	$recap_lang['ms'] = 'Malay';
-	$recap_lang['ml'] = 'Malayalam';
-	$recap_lang['mr'] = 'Marathi';
-	$recap_lang['mn'] = 'Mongolian';
-	$recap_lang['no'] = 'Norwegian';
-	$recap_lang['fa'] = 'Persian';
-	$recap_lang['pl'] = 'Polish';
-	$recap_lang['pt'] = 'Portuguese';
-	$recap_lang['pt-BR'] = 'Portuguese (Brazil)';
-	$recap_lang['pt-PT'] = 'Portuguese (Portugal)';
-	$recap_lang['ro'] = 'Romanian';
-	$recap_lang['ru'] = 'Russian';
-	$recap_lang['sr'] = 'Serbian';
-	$recap_lang['si'] = 'Sinhalese';
-	$recap_lang['sk'] = 'Slovak';
-	$recap_lang['sl'] = 'Slovenian';
-	$recap_lang['es'] = 'Spanish';
-	$recap_lang['es-419'] = 'Spanish (Latin America)';
-	$recap_lang['sw'] = 'Swahili';
-	$recap_lang['sv'] = 'Swedish';
-	$recap_lang['ta'] = 'Tamil';
-	$recap_lang['te'] = 'Telugu';
-	$recap_lang['th'] = 'Thai';
-	$recap_lang['tr'] = 'Turkish';
-	$recap_lang['uk'] = 'Ukrainian';
-	$recap_lang['ur'] = 'Urdu';
-	$recap_lang['vi'] = 'Vietnamese';
-	$recap_lang['zu'] = 'Zulu';
+	$post_type = array('post', 'page', 'product');
 	
+	$support_ept = get_option( 'pl_support_ept', ['post', 'page']);
+	foreach ( $support_ept as $support_pl ) {
+		add_post_type_support( $support_pl, 'pagelayer' );
+	}
+
 	pagelayer_page_header('Pagelayer Settings');
 	
 ?>
 	<form class="pagelayer-setting-form" method="post" action="">
-		<?php wp_nonce_field('pagelayer-options'); ?>
 		<div class="tabs-wrapper">
 			<h2 class="nav-tab-wrapper pagelayer-wrapper">
-				<?php
-				if(!defined('SITEPAD')){
-					echo '<a href="#general" class="nav-tab">'.__('General').'</a>';
-				}
-				?>
-				<a href="#icons" class="nav-tab "><?php _e('Enable Icons');?></a>
-				<a href="#social" class="nav-tab"><?php _e('Information');?></a>
+				<a href="#general" class="nav-tab">General</a>
+				<a href="#settings" class="nav-tab ">Settings</a>
+				<a href="#icons" class="nav-tab ">Enable Icons</a>
+				<a href="#social" class="nav-tab">Information</a>
 				<?php if(defined('PAGELAYER_PREMIUM')){ ?>
-				<a href="#integration" class="nav-tab"><?php _e('Integrations');?></a>
-				<a href="#contactform" class="nav-tab "><?php _e('Contact Form');?></a>
-				<a href="#captcha" class="nav-tab "><?php _e('Google Captcha');?></a>
-				<?php  
-				}
-				if(!defined('SITEPAD')){
-					echo '
-					<a href="#support" class="nav-tab ">'.__('Support').'</a>
-					<a href="#faq" class="nav-tab ">'.__('FAQ').'</a>';
-				}
-				?>
+				<a href="#integration" class="nav-tab">Integrations</a>
+				<a href="#contactform" class="nav-tab ">Contact Form</a>
+				<a href="#captcha" class="nav-tab ">Google Captcha</a>
+				<?php } ?>
+				<a href="#support" class="nav-tab ">Support</a>
+				<a href="#faq" class="nav-tab ">FAQ</a>
 			</h2>
 		
 			<div class="pagelayer-tab-panel" id="general">
 				 <table>
 					<tr>
-						<th scope="row"><?php _e('Editor Enables On');?></th>
+						<th scope="row">Editor Enables On </th>
 						<td>
 						<label>
 					<?php
-						foreach($post_type as $type => $name){							
-							echo '<input type="checkbox" name="pl_support_ept[]" value="'.$type.'" '. (in_array($type, $support_ept) ? "checked" : "") .'/>'.$name.'</br>';
+						foreach($post_type as $type){
+							
+							echo '<input type="checkbox" name="pl_support_ept[]" value="'.$type.'" '. (in_array($type, $support_ept) ? "checked" : "") .'/>'.$type.'</br>';
 						}
 					?>
 						</label>
@@ -419,10 +460,59 @@ function pagelayer_settings_page(){
 					</tr>
 				 </table>
 			</div>
+			<div class="pagelayer-tab-panel" id="settings">
+				<table>
+					<tr>
+						<th>Content Width</th>
+						<td>
+							<input name="pagelayer_content_width" type="number" step="1" min="320" max="5000" placeholder="1170" <?php if(get_option('pagelayer_content_width')){
+								echo 'value="'.get_option('pagelayer_content_width').'"';
+							}?>>
+							<p>Set the custom width of the content area. The default width set is 1170px</p>
+						</td>
+					<tr>
+					<tr>
+						<th>Space Between Widgets</th>
+						<td>
+							<input name="pagelayer_between_widgets" type="number" step="1" min="0" max="500" placeholder="15" <?php if(get_option('pagelayer_between_widgets')){
+								echo 'value="'.get_option('pagelayer_between_widgets').'"';
+							}?>>
+							<p>Set the Space Between Widgets. The default Space set is 15px</p>
+						</td>
+					<tr>
+					<tr>
+						<th>Body Font</th>
+						<td>
+							<input name="pagelayer_body_font" type="text" placeholder="Open Sans" <?php if(get_option('pagelayer_body_font')){
+								echo 'value="'.get_option('pagelayer_body_font').'"';
+							}?>>
+							<p>Please give font name as it appears on Google fonts site. You can check all google fonts here: <a href="https://fonts.google.com" target="_blank">https://fonts.google.com</a></p>
+						</td>
+					<tr>
+					<tr>
+						<th>Tablet Breakpoint</th>
+						<td>
+							<input name="pagelayer_tablet_breakpoint" type="number" step="1" min="320" max="5000" placeholder="768" <?php if(get_option('pagelayer_tablet_breakpoint')){
+								echo 'value="'.get_option('pagelayer_tablet_breakpoint').'"';
+							}?>>
+							<p>Set the breakpoint for tablet devices. The default breakpoint for tablet layout is 768px</p>
+						</td>
+					</tr>
+					<tr>
+						<th>Mobile Breakpoint</th>
+						<td>
+							<input name="pagelayer_mobile_breakpoint" type="number" step="1" min="320" max="5000" placeholder="360" <?php if(get_option('pagelayer_mobile_breakpoint')){
+								echo 'value="'.get_option('pagelayer_mobile_breakpoint').'"';
+							}?>>
+							<p>Set the breakpoint for mobile devices. The default breakpoint for mobile layout is 360px</p>
+						</td>
+					</tr>
+				</table>
+			</div>
 			<div class="pagelayer-tab-panel" id="icons">
 				<table>
 					<tr>
-						<th scope="row"><?php _e('Enable Icons');?></th>
+						<th scope="row">Enable Icons</th>
 						<td>
 						<label>
 							<input type="checkbox" name="pagelayer_icons_set[]" value="font-awesome5" <?php if(in_array('font-awesome5',get_option( 'pagelayer_icons_set')) || !get_option( 'pagelayer_icons_set')){echo ' checked';}?> />font-awesome5</br>
@@ -435,23 +525,23 @@ function pagelayer_settings_page(){
 				<div class="pagelayer-settings-info" style="display:flex;">
 					<div style="flex:1">
 						<div class="pagelayer-title">
-							<h2><?php _e('Address and Phone Number');?></h2>
+							<h2>Address and Phone Number</h2>
 						</div>
 						<table>
 							<tr>
-								<th><?php _e('Address');?></th>
+								<th>Address</th>
 								<td><textarea name="pagelayer-address"><?php echo pagelayer_get_option('pagelayer-address');?></textarea></td>
 							</tr>
 							<tr>
-								<th><?php _e('Phone Number');?></th>
+								<th>Phone Number</th>
 								<td><input type="tel" name="pagelayer-phone" <?php echo 'value="'.pagelayer_get_option('pagelayer-phone').'"';?> /></td>
 							</tr>
 							
 							<tr>
-								<th scope="row"><?php _e('Contact Email');?></th>
+								<th scope="row">Contact Email:</th>
 								<td>
 									<?php if(defined('PAGELAYER_PREMIUM')){																			
-										echo '<p>'.__('You can change your contact email<br> from the Contact Form Settings.').'</p>';
+										echo '<p>You can change your contact email<br> from the Contact Form Settings.</p>';									
 									}else{
 									?>
 									<label>
@@ -466,11 +556,11 @@ function pagelayer_settings_page(){
 						</table>
 						<?php if(defined('PAGELAYER_PREMIUM')){ ?>
 						<div class="pagelayer-title">
-							<h2><?php _e('Copyright');?></h2>
+							<h2>Copyright</h2>
 						</div>
 						<table>
 							<tr>
-								<th><?php _e('Copyright Text');?></th>
+								<th>Copyright Text</th>
 								<td><textarea name="pagelayer-copyright"><?php echo pagelayer_get_option('pagelayer-copyright'); ?></textarea></td>
 							</tr>
 						</table>
@@ -479,31 +569,31 @@ function pagelayer_settings_page(){
 					<?php if(defined('PAGELAYER_PREMIUM')){ ?>
 					<div style="flex:1">
 						<div class="pagelayer-title">
-							<h2><?php _e('Social Profile URLs');?></h2>
+							<h2>Social Profile URLs</h2>
 						</div>
 						<table>
 							<tr>
-								<th><?php _e('Facebook');?></th>
+								<th>Facebook</th>
 								<td><input type="text" name="pagelayer-facebook-url" <?php echo 'value="'.get_option('pagelayer-facebook-url').'"';?>/></td>
 							</tr>
 							<tr>
-								<th><?php _e('Twitter');?></th>
+								<th>Twitter</th>
 								<td><input type="text" name="pagelayer-twitter-url" <?php echo 'value="'.get_option('pagelayer-twitter-url').'"';?>/></td>
 							</tr>
 							<tr>
-								<th><?php _e('Instagram');?></th>
+								<th>Instagram</th>
 								<td><input type="text" name="pagelayer-instagram-url" <?php  echo 'value="'.get_option('pagelayer-instagram-url').'"'; ?>/></td>
 							</tr>
 							<tr>
-								<th><?php _e('LinkedIn');?></th>
+								<th>LinkedIn</th>
 								<td><input type="text" name="pagelayer-linkedin-url" <?php echo 'value="'.get_option('pagelayer-linkedin-url').'"'; ?>/></td>
 							</tr>
 							<tr>
-								<th><?php _e('YouTube');?></th>
+								<th>YouTube</th>
 								<td><input type="text" name="pagelayer-youtube-url" <?php echo 'value="'.get_option('pagelayer-youtube-url').'"'; ?>/></td>
 							</tr>
 							<tr>
-								<th><?php _e('Google+');?></th>
+								<th>Google+</th>
 								<td><input type="text" name="pagelayer-gplus-url" <?php echo 'value="'.get_option('pagelayer-gplus-url').'"'; ?>/></td>
 							</tr>
 						</table>
@@ -514,26 +604,21 @@ function pagelayer_settings_page(){
 			<?php if(defined('PAGELAYER_PREMIUM')){ ?>
 			<div class="pagelayer-tab-panel" id="integration">
 				<div class="pagelayer-title">
-					<h2><?php _e('Facebook SDK Details');?></h2>
+					<h2>Facebook SDK Details</h2>
 				</div>
 				<table>
 					<tr>
-						<th><?php _e('App ID');?></th>
+						<th>App ID</th>
 						<td><input type="text" name="pagelayer-fbapp-id" class="pagelayer-app-id" <?php if(get_option('pagelayer-fbapp-id')){
 								echo 'value="'.get_option('pagelayer-fbapp-id').'"';
 							}?>/></td>
 					</tr>					
 				</table>
 			</div>
-			<div class="pagelayer-tab-panel pagelayer-cf" id="contactform">
+			<div class="pagelayer-tab-panel" id="contactform">
 				 <table>
 					<tr>
-						<td colspan="2" style="align:middle;">
-						<p><?php _e('You can use a field name with a prefix $ to print your field value e.g. if the field name is <b>fieldname</b> then use the variable <b>$fieldname</b>');?></p>
-						</td>
-					</tr>
-					<tr>
-						<th scope="row"><?php _e('To Email');?>:</th>
+						<th scope="row">To Email:</th>
 						<td>
 							<label>
 								<input name="pagelayer_cf_to_email" type="email" placeholder="email@domain.com" <?php if(get_option('pagelayer_cf_to_email')){
@@ -543,18 +628,7 @@ function pagelayer_settings_page(){
 						</td>
 					</tr>
 					<tr>
-						<th scope="row"><?php _e('From Email');?>:</th>
-						<td>
-							<label>
-								<input name="pagelayer_cf_from_email" type="text" placeholder="My Site <email@domain.com>" <?php 
-								if(get_option('pagelayer_cf_from_email')){
-								echo 'value="'.get_option('pagelayer_cf_from_email').'"';
-							}?>/>
-							</label>
-						</td>
-					</tr>
-					<tr>
-						<th scope="row"><?php _e('Subject');?>:</th>
+						<th scope="row">Subject:</th>
 						<td>
 							<label>
 								<input name="pagelayer_cf_subject" type="text" placeholder="Subject" <?php if(get_option('pagelayer_cf_subject')){
@@ -564,21 +638,7 @@ function pagelayer_settings_page(){
 						</td>
 					</tr>
 					<tr>
-						<th scope="row"><?php _e('Additional Headers');?>: </th>
-						<td>
-							<label>
-								<textarea rows="3" name="pagelayer_cf_headers"><?php 
-								if(get_option('pagelayer_cf_headers')){
-									echo get_option('pagelayer_cf_headers');
-								} ?></textarea>
-							</label>
-						</td>
-					</tr>
-					<tr>
-						<td colspan="2"><b><?php echo __('Messages').' : </b><p>'.__('You can edit messages used for information of your form here.');?></p></td>
-					</tr>
-					<tr>
-						<th scope="row"><?php _e('Success Message');?> :</th>
+						<th scope="row">Success Message:</th>
 						<td>
 							<label>
 								<input name="pagelayer_cf_success" type="text" placeholder="Success" <?php if(get_option('pagelayer_cf_success')){
@@ -588,7 +648,7 @@ function pagelayer_settings_page(){
 						</td>
 					</tr>
 					<tr>
-						<th scope="row"><?php _e('Failed Message');?> :</th>
+						<th scope="row">Failed Message:	</th>
 						<td>
 							<label>
 								<input name="pagelayer_cf_failed" type="text" placeholder="Failed" <?php if(get_option('pagelayer_cf_failed')){
@@ -597,72 +657,38 @@ function pagelayer_settings_page(){
 							</label>
 						</td>
 					</tr>
-					<tr>
-						<th scope="row"><?php _e('reCaptcha Failed Message');?> : </th>
-						<td>
-							<label>
-								<input name="pagelayer_recaptcha_failed" type="text" placeholder="The CAPTCHA verification failed. Please try again." <?php
-								echo 'value="'.get_option('pagelayer_recaptcha_failed', __pl('cap_ver_fail')).'"';
-							?> />
-							</label>
-						</td>
-					</tr>
 				 </table>
 			</div>
 			<div class="pagelayer-tab-panel" id="captcha">
 				 <table>
 					<tr>
-						<th scope="row"><?php _e('reCaptcha Site Key');?></th>
+						<th scope="row">Google ReCaptcha </th>
 						<td>
 							<label>
-								<input name="pagelayer_google_captcha" type="text" placeholder="Site key" <?php if(get_option('pagelayer_google_captcha')){
+								<input name="pagelayer_google_captcha" type="text" placeholder="captcha" <?php if(get_option('pagelayer_google_captcha')){
 								echo 'value="'.get_option('pagelayer_google_captcha').'"';
 							}?> />
 							</label>
 						</td>
 					</tr>
-					<tr>
-						<th scope="row"><?php _e('reCaptcha Secret Key');?></th>
-						<td>
-							<label>
-								<input name="pagelayer_google_captcha_secret" type="text" placeholder="Secret key" <?php if(get_option('pagelayer_google_captcha_secret')){
-								echo 'value="'.get_option('pagelayer_google_captcha_secret').'"';
-							}?> />
-							</label>
-						</td>
-					</tr>
-					<tr>
-						<th scope="row"><?php _e('reCaptcha Language');?> </th>
-						<td>
-							<label>
-								<select name="pagelayer_google_captcha_lang">
-									<?php
-										foreach($recap_lang as $k => $v){
-											echo '<option '.( get_option('pagelayer_google_captcha_lang', '') == $k ? 'selected="selected"' : '').' value="'.$k.'">'.$v.'</value>';								
-										}
-									?>
-								</select>
-							</label>
-						</td>
-					</tr>
 				 </table>
 			</div>
 			<?php } ?>
 			<div class="pagelayer-tab-panel" id="support">
-				<h2><?php _e('Support');?></h2>
-				<h3><?php _e('You can contact the Pagelayer Team via email. Our email address is <a href="mailto:support@pagelayer.com">support@pagelayer.com</a>. We will get back to you as soon as possible!');?></h3>
+				<h2>Support</h2>
+				<h3>You can contact the Pagelayer Team via email. Our email address is <a href="mailto:support@pagelayer.com">support@pagelayer.com</a>. We will get back to you as soon as possible!</h3>
 			</div>
 			<div class="pagelayer-tab-panel" id="faq">
-				<h2><?php _e('FAQ');?></h2>
+				<h2>FAQ</h2>
 				<div class="pagelayer-acc-wrapper">
-					<span class="nav-tab pagelayer-acc-tab"><?php _e('1: Why choose us');?></span>
+					<span class="nav-tab pagelayer-acc-tab">1: Why choose us</span>
 					<div class="pagelayer-acc-panel">
-						<p><?php _e('Pagelayer is best live editor and easy to use and we will keep improving it !');?></P>
+						<p>Pagelayer is best live editor and easy to use and we will keep improving it !</P>
 					</div>
 					
-					<span class="nav-tab pagelayer-acc-tab"><?php _e('2: Support');?></span>
+					<span class="nav-tab pagelayer-acc-tab">2: Support</span>
 					<div class="pagelayer-acc-panel">
-						<p><?php _e('You can contact the PageLayer Group via email. Our email address is <a href="mailto:support@pagelayer.com">support@pagelayer.com</a>. We will get back to you as soon as possible!');?></p>
+						<p>You can contact the PageLayer Group via email. Our email address is <a href="mailto:support@pagelayer.com">support@pagelayer.com</a>. We will get back to you as soon as possible!</p>
 					</div>
 				</div>
 			</div>
@@ -676,4 +702,4 @@ function pagelayer_settings_page(){
 	
 	pagelayer_page_footer();
 
-}
\ No newline at end of file
+}
